package com.ruoyi.generator.mapper;

import java.util.List;
import com.ruoyi.generator.domain.SysModule;

/**
 * 功能模块Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-09
 */
public interface SysModuleMapper 
{
    /**
     * 查询功能模块
     * 
     * @param moduleId 功能模块主键
     * @return 功能模块
     */
    public SysModule selectSysModuleByModuleId(Long moduleId);

    /**
     * 查询功能模块列表
     * 
     * @param sysModule 功能模块
     * @return 功能模块集合
     */
    public List<SysModule> selectSysModuleList(SysModule sysModule);

    /**
     * 新增功能模块
     * 
     * @param sysModule 功能模块
     * @return 结果
     */
    public int insertSysModule(SysModule sysModule);

    /**
     * 修改功能模块
     * 
     * @param sysModule 功能模块
     * @return 结果
     */
    public int updateSysModule(SysModule sysModule);

    /**
     * 删除功能模块
     * 
     * @param moduleId 功能模块主键
     * @return 结果
     */
    public int deleteSysModuleByModuleId(Long moduleId);

    /**
     * 批量删除功能模块
     * 
     * @param moduleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysModuleByModuleIds(Long[] moduleIds);
}
