package com.ruoyi.generator.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.generator.domain.SysModule;
import com.ruoyi.generator.service.ISysModuleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 功能模块Controller
 * 
 * @author ruoyi
 * @date 2025-05-09
 */
@RestController
@RequestMapping("/generator/module")
public class SysModuleController extends BaseController
{
    @Autowired
    private ISysModuleService sysModuleService;

    /**
     * 查询功能模块列表
     */
    @PreAuthorize("@ss.hasPermi('generator:module:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysModule sysModule)
    {
        startPage();
        List<SysModule> list = sysModuleService.selectSysModuleList(sysModule);
        return getDataTable(list);
    }

    /**
     * 导出功能模块列表
     */
    @PreAuthorize("@ss.hasPermi('generator:module:export')")
    @Log(title = "功能模块", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysModule sysModule)
    {
        List<SysModule> list = sysModuleService.selectSysModuleList(sysModule);
        ExcelUtil<SysModule> util = new ExcelUtil<SysModule>(SysModule.class);
        util.exportExcel(response, list, "功能模块数据");
    }

    /**
     * 获取功能模块详细信息
     */
    @PreAuthorize("@ss.hasPermi('generator:module:query')")
    @GetMapping(value = "/{moduleId}")
    public AjaxResult getInfo(@PathVariable("moduleId") Long moduleId)
    {
        return success(sysModuleService.selectSysModuleByModuleId(moduleId));
    }

    /**
     * 新增功能模块
     */
    @PreAuthorize("@ss.hasPermi('generator:module:add')")
    @Log(title = "功能模块", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysModule sysModule)
    {
        return toAjax(sysModuleService.insertSysModule(sysModule));
    }

    /**
     * 修改功能模块
     */
    @PreAuthorize("@ss.hasPermi('generator:module:edit')")
    @Log(title = "功能模块", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysModule sysModule)
    {
        return toAjax(sysModuleService.updateSysModule(sysModule));
    }

    /**
     * 删除功能模块
     */
    @PreAuthorize("@ss.hasPermi('generator:module:remove')")
    @Log(title = "功能模块", businessType = BusinessType.DELETE)
	@DeleteMapping("/{moduleIds}")
    public AjaxResult remove(@PathVariable Long[] moduleIds)
    {
        return toAjax(sysModuleService.deleteSysModuleByModuleIds(moduleIds));
    }
}
